@@ -8,10 +8,13 @@ make clean
 # Get the tarball
 make dist
 
+. automation/set_release_suffix.sh
+
 # create the src.rpm
 rpmbuild \
     -D "_srcrpmdir $PWD/output" \
     -D "_topmdir $PWD/rpmbuild" \
+    ${release_suffix:+-D "release_suffix ${release_suffix}"} \
     -ts ./*.gz
 
 # install any build requirements
@@ -21,6 +24,7 @@ yum-builddep output/*src.rpm
 rpmbuild \
     -D "_rpmdir $PWD/output" \
     -D "_topmdir $PWD/rpmbuild" \
+    ${release_suffix:+-D "release_suffix ${release_suffix}"} \
     --rebuild output/*.src.rpm
 
 # Store any relevant artifacts in exported-artifacts for the ci system to
